@@ -3,14 +3,15 @@
 import argparse
 import yaml
 import os
-from ybase import YBase
-from yaml_worker import YamlActionsWorker
+# from ybase import YBase
+# from yaml_worker import YamlActionsWorker
 
 import sys
 
 
 def main():
-    sys.path.append('src/yamlbase')
+
+    sys.path.append('src/YamlBase')
 
     with open('src/yamlbase/descriptions_cfg.yaml') as f:
         descriptions = yaml.load(f)
@@ -23,8 +24,8 @@ def main():
 
     args = parser.parse_args()
 
-    base = YBase(args.cfg_path, args.action)
-    base.do_actions()
+    # base = YBase(args.cfg_path, args.action)
+    # base.do_actions()
 
 
 if __name__ == '__main__':
